无人知晓 (豆瓣)
Description: 无人知晓电影简介和剧情介绍,无人知晓影评、图片、预告片、影讯、论坛、在线购票
Keywords: 无人知晓,誰も知らない,无人知晓影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.120豆瓣电影Top250

# 无人知晓 誰も知らない (2004)

导演: 是枝裕和
编剧: 是枝裕和
主演: 柳乐优弥 / 北浦爱 / 木村飞影 / 清水萌萌子 / 韩英惠 / 江原由希子 / 串田和美 / 冈元夕纪子 / 楯隆子 / 加濑亮 / 村野友希 / 田中庆太 / 木村佑一 / 远藤宪一 / 寺岛进 / 平泉成
类型: 剧情
制片国家/地区: 日本
语言: 日语
上映日期: 2004-05-13(戛纳电影节) / 2004-08-07(日本)
片长: 141分钟
又名: 谁知赤子心(港) / 无人知晓的夏日清晨(台) / Nobody Knows / Dare mo shiranai
IMDb: tt0408664
豆瓣评分
引用
9.1
300402人评价
5星
62.6%
4星
32.0%
3星
4.9%
2星
0.4%
1星
0.2%
好于 98% 剧情片
想看 看过
评价:
推荐

## 无人知晓的剧情简介 · · · · · ·

新搬来的公寓这家人是母亲惠子（You饰）带着四个孩子：明（柳乐优弥饰）、京子、茂、雪。但母亲却得对周围的人们撒谎说丈夫去海外工作，自己与长子两个人在一起生活。事实是其它三名弟妹是“黑孩子”，因为四个孩子有着各自不同的父亲。他们一直呆在家中，没有去学校上学。
在母亲去百货商店工作时，年纪尚小的明就在家中代替母亲行使家长的职责。突然有一天母亲不见了，她把手中仅有的20万日元现金和一张短短的便条留给了孩子们，把弟妹托付给明看管后，就悄然地离家出走。
无亲无故，对外面几乎一无所知的四个孩子们，要开始面对新的生活，那实在不是件容易的事情…… ©豆瓣

## 无人知晓的演职员 · · · · · · ( 全部 20 )

- 是枝裕和 导演
- 柳乐优弥 饰 福島明
- 北浦爱 饰 福島京子
- 木村飞影 饰 福島茂
- 清水萌萌子 饰 福島ゆき
- 韩英惠 饰 水口紗希

## 无人知晓的视频和图片 · · · · · · ( 视频评论1 · 添加 | 图片962 · 添加 )

## 无人知晓的获奖情况 · · · · · · ( 全部 )

- 第57届戛纳电影节
- 主竞赛单元 金棕榈奖(提名)
- 是枝裕和

- 第28届日本电影学院奖
- 最佳女配角(提名)
- 江原由希子

- 第29届报知映画赏
- 最佳影片
- 是枝裕和

## 喜欢这部电影的人也喜欢 · · · · · ·

  步履不停

  如父如子

  比海更深

  东京物语

  饮食男女

  海街日记

  小偷家族

  奇迹

  一一

  海边的曼彻斯特

我要写短评

## 无人知晓的短评 · · · · · · ( 全部 89119 条 )

热门 / 最新 / 好友

### 4949 有用 海獭 看过 2009-07-21 22:46:09

家中早已经没有了妈妈，生活早已经很拮据，水电早已经停了，今天吃过的泡面汤要留作明天拌饭，喜爱画画就画在水电停用通知单上，从公园偷水饮用，把摔死的妹妹埋掉......这一切，都没有人知道

### 3704 有用 半袖 看过 2009-09-12 16:07:19

看完以后，也还是沉默，没有煽情的眼泪，没有明显的愤怒，就和这部电影一样，平静的说一个难过的故事，但没有一个人流泪，甚至连埋怨都没有。被抛弃真的很可怕。

### 3335 有用 It's OK 看过 2009-08-19 20:40:36

男孩一次也没有掉过泪，你看见了吗。

### 1608 有用 Connie 看过 2009-10-07 12:09:57

身为人母居然能无耻到这个地步也算奇观一件

### 2196 有用 桃桃林林 看过 2010-08-21 11:04:04

真是可爱的孩子啊。从《距离》之后，是枝裕和的电影就越来越生活化，有些纪实的风格，琐碎的生活细节，两个小孩甚至算不上表演，即兴发挥的表演也让这部电影充满了生活气息。更难得的是，面对这种狗血的题材，是枝裕和却并没有煽情和大喊大叫，只是让所有角色一起忍耐、承受着，连同观众一起

> 更多短评 89119条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 无人知晓的影评 · · · · · · ( 全部 1409 条 )

热门 / 最新 / 好友
柏邦妮 2009-10-04 00:48:04

## 无人知晓的时间

无人知晓的时间 柏邦妮 《无人知晓》，是日本导演是枝裕和根据真实案例改编的一部电影。主要内容是讲一个叫福岛惠子的单身母亲，生养了四个小孩，分别是十二岁的长子明，十一岁的女儿京子，五岁的儿子茂，以及三岁的女儿小雪。这四个孩子，来自四个身份不明的缺席的父亲。惠... (展开)
5149 241 200回应 收起
叶习习 2007-02-10 00:45:42

## 事实

这篇影评可能有剧透

1988年1月東京西巢鴨地區一名母親為與男友同居，留下長子（14歲）及三名分別七歲、三歲及兩歲的女兒在家。四名孩子無戶籍，亦沒有上學。其後兩歲的幼女因偷吃長子損友的杯麵而被毒打致死，當中長子亦有踢傷妹妹，之後把屍體埋到埼玉縣秩父市公園。同年7月鄰居發現該屋長期... (展开)
1617 87 338回应 收起
艾小柯 2010-04-02 07:37:33

## 黑色的河流

日本导演是枝裕和2004年的电影《无人知晓》取材于一则真实的社会新闻：1988年一月，日本东京西巢鸭地区一名母亲为了与新男友同居，抛弃了四名子女。14岁的长子独自抚养分别7岁、3岁及2岁的妹妹，公寓凌乱，小孩白天亦不上学，四处游荡。3岁的妹妹因偷吃了长子朋友的泡面，被毒... (展开)
1647 97 75回应 收起
U·U 2011-03-27 17:57:51

## 西巢鸭弃婴事件

西巢鸭弃婴事件 (来自网上） 　　 　　 一个女人跟一个男人生了一个儿子，三口子住在一起。男人跟女人说，已经去帮他们的婚姻和孩子做过登记，所以一切都合法没问题。当孩子六岁却还没有收到叫孩子去上小学的通知单时，女人跑去有关单位询问，才知道男人骗了她.. 不管是婚姻还... (展开)
1417 90 101回应 收起
nahua 2013-06-21 12:38:09

## 《无人知晓》花絮采访

DVD花絮的采访，手动翻译视频转文字，如有错误欢迎指正。 花絮采访：高桥论治 摄影：山崎裕 是枝：“十五年前最初写剧本的时候，听到人们说的最多的还是：这个不行吧，大家都觉得这个无法拍成电影。大家都觉得这样拍出来，没有人愿意看，经历了如此种种，结果放映当天人满为患... (展开)
425 9 14回应 收起
bluegrass 2006-01-09 19:53:14

## 几个月前看过，至今难忘

我知道，很多人看韩剧台剧会很投入，尤其是整天哭哭啼啼的韩剧，有些，几乎所有的戏份都是哭戏，可是，我从来都不觉得想哭，总觉得太矫情，太做作。不喜欢这种整天要把悲伤写在脸上告诉全世界的剧情，不喜欢这种把眼泪当作唯一武器的戏，也许主人公的命运真的很坎坷，可是不停... (展开)
448 74 78回应 收起
袋鼠花 2010-03-13 00:38:41

## 一个被美化的残酷故事依然残酷

这篇影评可能有剧透

我首先将真实的时间清除出去，完全接受是枝裕和的时刻表。然后把自己想像成一株爬山虎，以四季为单位，非常缓慢地攀援。渐渐地，是枝裕和的镜头，以一以贯之的精准和淡定，牵引着我的触角，潜入这块被人遗忘、无人知晓的小小天地。 这是一个弱者抛弃弱者引发的悲剧。始作俑者... (展开)
229 4 8回应 收起
逍遥逍遥 2017-11-01 04:40:42

## 真实事件完整版

这篇影评可能有剧透

1988年夏天，东京巢鸭署的署员接到辖区内一个房东投诉，有套外租公寓缺欠租金多月，而且找不到大人，只有小孩。上门查访发现，只有一个14岁大的男孩、两个分别7岁与3岁的女孩，共三个孩子，在这个没有瓦斯没有电、垃圾场一般、散发恶臭的公寓里相依为命。 进一步搜索，又在公寓... (展开)
135 1 18回应 收起
阿贝阿 2007-04-12 19:37:52

## 阴翳里的明亮调子

看了十分钟《无人知晓》，就知道是枝裕和是我爱喝的那杯茶，和小津和阿孝咕他们是一国的，虽然风格上有轻微的差异。  家庭生活，简单的人物关系，极简的对话，平平静静地把创痛剧深的故事讲出来。本来以为会很压抑的片子，却始终有一种阴翳里的明亮调子，不时响起的淡淡明... (展开)
122 13 8回应 收起
苍衣社 2017-11-21 10:35:04

## 温暖和冷漠共存，这才是无人知晓想讲述的

这篇影评可能有剧透

你14岁的时候，又一次跑去跟妹妹的生父借钱。他躺在自己的计程车里睡觉，你不敢打扰他，在修车厂的废弃轮胎上忐忑的等待着这个男人沉睡的结束。 不知道过了多久，他终于醒了，走出车外，没有看你一眼。你一脸平静，视线黏在了他身上，好像一个隐形的人。 《无人知晓》中一个简... (展开)
128 7 7回应 收起

> 更多影评 1409篇

添加新讨论

## 讨论区 · · · · · ·

好后悔看这片 | 来自allmi | 1 回应 | 2022-11-18 16:32:22
类似这样的电影，他到底想告诉我们什么？他想传达... | 来自伊于胡底 | 32 回应 | 2022-11-07 21:19:51
有人知道真实故事和后面的情况吗？ | 来自果力橙 | 5 回应 | 2022-11-05 22:07:42
关于京子的指甲油有谁能帮我解答一下？ | 来自杨升升 | 15 回应 | 2022-10-27 00:28:17
是我想多了么？真的是陪唱歌？ | 来自Jailbreak | 22 回应 | 2022-10-22 13:51:03

> 去这部影片的讨论区（全部211条）

## 关于《无人知晓》的问题 · · · · · · ( 全部27个 )

- 为什么明的弟弟妹妹不能出门？出门被发现会有什么后果？ 2人回答
- 和步履不停一样用江原由希子的声音开场，有什么用意吗？ 5人回答

> 全部27个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 VIP免费观看
- 腾讯视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 【真实犯罪】—— 真人真事改编案件（世界版1） (狷介有乌青)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 日式青春 (沉歌)

## 谁在看这部电影 · · · · · ·

- Persis
  2分钟前 看过
- 漆柒
  5分钟前 想看
- 要成为开心怪👻
  13分钟前 想看

415198人看过 / 345049人想看

订阅无人知晓的评论:
feed: rss 2.0